/*
 * Created on Apr 13, 2005
 *
 */
package com.sunlabs.archsim.fleet.HornAndFunnel;

import java.util.LinkedList;

import com.sunlabs.archsim.base.common.Parameters;
import com.sunlabs.archsim.fleet.common.FleetGlobal;
import com.sunlabs.archsim.gasp.Component;
import com.sunlabs.archsim.gasp.Terminal;
import com.sunlabs.archsim.gasp.terminals.InputTerminal;
import com.sunlabs.archsim.gasp.terminals.OutputTerminal;

/**
 *
 * Copyright  2005 Sun Microsystems Inc. All rights reserved. Use is subject to license terms.
 * 
 * @author ib27688
 *
 * Attach terminals to SourceSyncAction
 */
public class SourceSync extends Component {

	public static final String SRC_SYNC_ACTION= "srcSyncAction";
	
	protected InputTerminal in;
	protected OutputTerminal ackIn;
	
	protected InputTerminal srcIn;
	protected OutputTerminal ackSrcIn;
	
	protected OutputTerminal out;
	protected InputTerminal ackOut;
	
	LinkedList<Terminal> terminalList;
	
	SourceSyncAction srcSyncAction;
	
	public SourceSync(String name, Parameters params) {
		super(name, null);
		
		if (params != null) {
			for (int i= 0; i<params.size(); i++) {
				String pName= params.getName(i);
				String sValue= params.getValue(i);
				// ignore all parametters
				director.error("Component: " + name + ", id= " + getID() 
						+ ": Attribute " + pName + " with value " + sValue
						+ " is ignored");							
			} // for
		} // if
		
	} // buildSourceSync
	
	public SourceSync(String name) {
		super(name, null);
		buildSourceSync();
	} // constructor
	
	protected void buildSourceSync() {
		srcSyncAction= new SourceSyncAction(SRC_SYNC_ACTION, this);
		
		in= new InputTerminal(FleetGlobal.IN, this);
		ackIn= new OutputTerminal(FleetGlobal.ACK_IN, this);
		
		srcIn= new InputTerminal(FleetGlobal.SRC_IN, this);
		ackSrcIn= new OutputTerminal(FleetGlobal.ACK_SRC_IN, this);
		
		out= new OutputTerminal(FleetGlobal.OUT, this);
		ackOut= new InputTerminal(FleetGlobal.ACK_OUT, this);
		
		srcSyncAction.attach(in);
		srcSyncAction.attach(ackIn);

		srcSyncAction.attach(srcIn);
		srcSyncAction.attach(ackSrcIn);

		srcSyncAction.attach(out);
		srcSyncAction.attach(ackOut);

		// make a list of terminals and insert terminals
		terminalList= new LinkedList<Terminal>();
		terminalList.add(in);
		terminalList.add(ackIn);
		terminalList.add(srcIn);
		terminalList.add(ackSrcIn);
		terminalList.add(out);
		terminalList.add(ackOut);
		
	} // buildSourceSync
	
	public InputTerminal getIn() {
		return in;
	}
	
	public OutputTerminal getAckIn() {
		return ackIn;
	}

	public InputTerminal getSrcIn() {
		return srcIn;
	}
	
	public OutputTerminal getAckSrcIn() {
		return ackSrcIn;
	}

	public InputTerminal getAckOut() {
		return ackOut;
	}
	
	public OutputTerminal getOut() {
		return out;
	}
	
	public Terminal getTerminal(String name) {
		Terminal result= null;
		for (Terminal t : terminalList) {
			if (t.getBaseName().equals(name) 
					|| t.getName().equals(name)
					|| t.getBaseAlias().equals(name)
					|| t.getAlias().equals(name)) {
				result= t;
				break;
			}
		}
		return result;
	}

	
} // SourceSync
