/*
 * Copyright  2005 Sun Microsystems Inc. All rights reserved. Use is subject to license terms.
 *  
 */

/*
 * Created on Nov 30, 2004
 *
 */
package com.sunlabs.archsim.testDriver;


import com.sunlabs.archsim.base.hierarchy.CompositeEntity;
import com.sunlabs.archsim.base.simulation.Delay;
import com.sunlabs.archsim.engine.Director;
import com.sunlabs.archsim.fleet.HornAndFunnel.TestFleet;
import com.sunlabs.archsim.tests.fifo.Fifo;
import com.sunlabs.archsim.tests.fifo.FifoFactory;
import com.sunlabs.archsim.tests.splitter.Splitter;
import com.sunlabs.archsim.tests.splitter.SplitterFactory;
import com.sunlabs.archsim.tests.splitter.SplitterInput;
import com.sunlabs.archsim.tests.splitter.SplitterOutput;
import com.sunlabs.archsim.tests.splitter.SplitterSink;
import com.sunlabs.archsim.tests.splitter.SplitterSource;

import com.sunlabs.archsim.tests.arbiter.ArbiterTest;
import com.sunlabs.archsim.tests.arbiter.ArbiterTestFactory;

import com.sunlabs.archsim.tests.actionarbiter.ActionArbiterTest;
import com.sunlabs.archsim.tests.actionarbiter.AATFactory;

import com.sunlabs.archsim.tests.branch.BranchTestFactory;

import com.sunlabs.archsim.tests.merge.MergeTestFactory;

import java.util.Date;

/**
 *
 * Copyright  2005 Sun Microsystems, Inc. All rights reserved. Use is subject to license terms.
 * 
 * @author ib27688
 *
 */
public class TestDriver {
	
	// enum Haha { one, two, three };
	
	

	public static void main/*Fleet*/(String[] args) {
		Director director= Director.getInstance();
		
		System.out.println("Fleet test started");
		
		CompositeEntity test= new TestFleet("test fleet", 2);
		
		System.out.println("Self check started.");
		if (test.selfCheck()) {
			System.out.println("self check passed");

			long start= (new Date()).getTime();
			director.reset();
	 		director.run(new Delay(1000));	
	 		long stop= (new Date()).getTime();
	 		long runtime= stop-start;
			System.out.println("Done in " + runtime + "ms.");
		}
	
		// test.printConnections();		
	}
	
	public static void mainMerge(String[] args) {
		Director director= Director.getInstance();
		
		System.out.println("Merge test started");
		
		CompositeEntity test= MergeTestFactory.please("MergeTest");
		
		System.out.println("Self check started.");
		if (test.selfCheck()) {
			System.out.println("self check passed");

			long start= (new Date()).getTime();
			director.reset();
			// test.print();
			// director.printQueue();
	 		director.run(new Delay(3000));	
	 		long stop= (new Date()).getTime();
	 		long runtime= stop-start;
			System.out.println("Done in " + runtime + "ms.");
		}
	
		// test.printConnections();
	}

	
	public static void mainBranch(String[] args) {
		Director director= Director.getInstance();
		
		System.out.println("Branch test started");
		
		CompositeEntity test= BranchTestFactory.please("branchTest");
		
		System.out.println("Self check started.");
		if (test.selfCheck()) {
			System.out.println("self check passed");

			long start= (new Date()).getTime();
	 		director.run(new Delay(3000));	
	 		long stop= (new Date()).getTime();
	 		long runtime= stop-start;
			System.out.println("Done in " + runtime + "ms.");
		}
	
		// test.printConnections();
	}
	
	public static void mainArbiterAction(String[] args) {
		Director director= Director.getInstance();
		
		ActionArbiterTest test= AATFactory.please("arbiterTest");
		
		if (test.selfCheck()) {
			System.out.println("self check passed");

			
			long start= (new Date()).getTime();
	 		director.run(new Delay(3000));	
	 		long stop= (new Date()).getTime();
	 		long runtime= stop-start;
			System.out.println("Done in " + runtime + "ms.");
		}
		
		// test.printConnections();
	} // main
	
	public static void mainArbiterTest(String[] args) {
		Director director= Director.getInstance();
		
		ArbiterTest arbiterTest= ArbiterTestFactory.please("arbiterTest");
		
		if (arbiterTest.selfCheck()) {
			System.out.println("self check passed");

			
			long start= (new Date()).getTime();
	 		director.run(new Delay(1000));	
	 		long stop= (new Date()).getTime();
	 		long runtime= stop-start;
			System.out.println("Done in " + runtime + "ms.");		
		}
		
		// arbiterTest.printConnections();
		
	} // main
	
	public static void mainSplitter(String[] args) {

		Director director= Director.getInstance();

		Splitter splitter= SplitterFactory.please("Test splitter", 5);
		
		SplitterSource src= new SplitterSource("SplitterSource", 64, 12);
		SplitterSink sink= new SplitterSink("SplitterSink");

		SplitterOutput dataOutTerminal= new SplitterOutput("dataOutTerminal");
		SplitterInput ackDataOutTerminal= new SplitterInput("ackDataOutTerminal");
		
		src.attach(dataOutTerminal);
		src.attach(ackDataOutTerminal);
		
		splitter.getDataIn().attach(dataOutTerminal);
		splitter.getAckDataIn().attach(ackDataOutTerminal);
		
		SplitterInput dataInTerminal= new SplitterInput("dataInTerminal");
		SplitterOutput ackDataInTerminal= new SplitterOutput("ackDataInTerminal");
		
		sink.attach(dataInTerminal);
		sink.attach(ackDataInTerminal);
		
		splitter.getDataOut().attach(dataInTerminal);
		splitter.getAckDataOut().attach(ackDataInTerminal);
		
		if (splitter.selfCheck()) {
			System.out.println("self check passed");
			// fifo.printConnections();
			
			splitter.getAckDataIn().setActive(null);
			splitter.getAckDataOut().setActive(null);
			
			long start= (new Date()).getTime();
	 		director.run(new Delay(1000));	
	 		long stop= (new Date()).getTime();
	 		long runtime= stop-start;
			System.out.println("Done in " + runtime + "ms.");
		}
	}
	
	
	public static void mainFIFO(String[] args) {
		// SimulateTwoWires s= new SimulateTwoWires();
		// s.execute();

		Director director= Director.getInstance();

		Fifo fifo= FifoFactory.please("SampleFifo", 10);

		
		if (fifo.selfCheck()) {
			System.out.println("self check passed");
		}
		
		// fifo.printConnections();
		
		long start= (new Date()).getTime();
 		director.run(new Delay(1000));
/*		director.run(new Delay(10));
		director.run(new Delay(10));

		
		director.run(new Delay(10));
		director.run(new Delay(10));
		director.run(new Delay(10));
*/	
 		long stop= (new Date()).getTime();
 		long runtime= stop-start;
		System.out.println("Done in " + runtime + "ms.");
	}
} // Simulator

 